# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class MethodInvoke(Component):
    """A MethodInvoke component.
A component exposing the ability to invoke a Glue42 Interop method.

Keyword arguments:

- id (optional):
    The ID of this component. Used to identify Dash components in
    callbacks.  The ID must be unique across all components in an app.

- invoke (dict; optional):
    Property for invoking an Interop method.

    `invoke` is a dict with keys:

    - argumentObj (dict; optional):
        Invocation arguments.

    - definition (string | dict; required):
        Method name or an object holding the method name, signature
        and other properties of the method.

    - invocationId (string; optional):
        An ID to correlate the method invocation to its result.

    - options (dict; optional):
        Property for specifying a timeout for discovering the invoked
        Interop method  and a timeout for receiving a response from
        the method.

        `options` is a dict with keys:

        - methodResponseTimeoutMs (number; optional):
            Timeout to wait for a method reply.

        - waitTimeoutMs (number; optional):
            Timeout to discover the method, if not immediately
            available.

    - target (string | dict | list of dicts; optional):
        Property for specifying a target Interop server.

- result (dict; optional):
    Property that returns a result or an error from a method
    invocation.

    `result` is a dict with keys:

    - error (dict; optional):
        An error for method invocation failure. Has a `None` value
        unless the invocation fails.

    - invocationId (string; optional):
        An ID to correlate the method invocation to its result.

    - invocationResult (dict; optional):
        The actual result from the method invocation. If the
        invocation fails, a `None` value is set.

- setProps (optional):
    Dash-assigned callback that should be called to report property
    changes to Dash in order to make them available for callbacks."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, result=Component.UNDEFINED, invoke=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'invoke', 'result', 'setProps']
        self._type = 'MethodInvoke'
        self._namespace = 'dash_glue42'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'invoke', 'result', 'setProps']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(MethodInvoke, self).__init__(**args)



from .Channels import Channels
from .Glue42 import Glue42
from .MethodInvoke import MethodInvoke
from .MethodRegister import MethodRegister
from .Notifications import Notifications
from .Context import Context
from .Contexts import Contexts
from .Windows import Windows

__all__ = [
    "Channels",
    "Glue42",
    "MethodInvoke",
    "MethodRegister",
    "Notifications",
    "Context",
    "Contexts",
    "Windows"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Channels(Component):
    """A Channels component.
A component exposing the Glue42 Channels API.

Keyword arguments:

- id (optional):
    The ID of this component. Used to identify Dash components in
    callbacks.  The ID must be unique across all components in an app.

- all (list of strings; optional):
    A list of all Channel names.

- join (dict; optional):
    Property for joining a new channel by name. Leaves the current
    channel.

    `join` is a dict with keys:

    - name (string; required):
        The name of the channel to join.

- leave (dict; optional):
    Property for leaving the current channel.

- list (list; optional):
    A list of all Channel contexts.

- my (optional):
    Holds the current Channel context. Value will be None when not
    joined to a channel.

- publish (dict; optional):
    Property for publishing new data to a Channel.

    `publish` is a dict with keys:

    - data (boolean | number | string | dict | list; optional):
        Data object with which to update the channel context.

    - name (string; optional):
        The name of the channel to be updated. If not provided will
        update the current channel.

- setProps (optional):
    Dash-assigned callback that should be called to report property
    changes to Dash in order to make them available for callbacks."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, list=Component.UNDEFINED, all=Component.UNDEFINED, my=Component.UNDEFINED, publish=Component.UNDEFINED, join=Component.UNDEFINED, leave=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'all', 'join', 'leave', 'list', 'my', 'publish', 'setProps']
        self._type = 'Channels'
        self._namespace = 'dash_glue42'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'all', 'join', 'leave', 'list', 'my', 'publish', 'setProps']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Channels, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Glue42(Component):
    """A Glue42 component.
The Glue42 initializer component. The component should be placed at the root of the application.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (optional):
    The ID of this component. Used to identify Dash components in
    callbacks.  The ID must be unique across all components in an app.

- fallback (a list of or a singular dash component, string or number; optional):
    An optional component to display while initializing Glue42.

- isEnterprise (boolean; optional):
    Indicates whether the application is running in Glue42 Enterprise
    or Glue42 Core.

- setProps (optional):
    Dash-assigned callback that should be called to report property
    changes to Dash in order to make them available for callbacks.

- settings (default {
    type: CoreApplicationTypes.Client,
}):
    A `settings` object containing configuration objects for the
    Glue42 library."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, isEnterprise=Component.UNDEFINED, settings=Component.UNDEFINED, fallback=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'fallback', 'isEnterprise', 'setProps', 'settings']
        self._type = 'Glue42'
        self._namespace = 'dash_glue42'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'fallback', 'isEnterprise', 'setProps', 'settings']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Glue42, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Context(Component):
    """A Context component.
A component exposing the ability to subscribe, set and update a Glue42 Shared Context.

Keyword arguments:

- id (optional):
    The ID of this component. Used to identify Dash components in
    callbacks.  The ID must be unique across all components in an app.
    The ID is used as the context name to subscribe for.

- context (dict; optional):
    Holds the latest context update.

    `context` is a dict with keys:

    - data (dict; optional)

    - delta (dict; optional)

    - removed (list of strings; optional)

- set (dict; optional):
    Property for setting a new context value.  All properties of the
    specified context object will be removed and replaced with the
    ones supplied in the data property.  An object that will replace
    the context value completely.

- setProps (optional):
    Dash-assigned callback that should be called to report property
    changes to Dash in order to make them available for callbacks.

- update (dict; optional):
    Property for updating a shared context with the supplied object.
    Updates only the specified context properties. Any other existing
    context properties will remain intact.  If the context does not
    exist, then it will be created."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, context=Component.UNDEFINED, update=Component.UNDEFINED, set=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'context', 'set', 'setProps', 'update']
        self._type = 'Context'
        self._namespace = 'dash_glue42'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'context', 'set', 'setProps', 'update']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Context, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Notifications(Component):
    """A Notifications component.
A component exposing the Glue42 Notifications API.

Keyword arguments:

- id (optional):
    The ID of this component. Used to identify Dash components in
    callbacks.  The ID must be unique across all components in an app.

- maxActions (number; optional):
    The maximum number of actions supported by the UI toast.

- raise (dict; optional):
    Property to raise a new notification.

- setProps (optional):
    Dash-assigned callback that should be called to report property
    changes to Dash in order to make them available for callbacks."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, maxActions=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'maxActions', 'raise', 'setProps']
        self._type = 'Notifications'
        self._namespace = 'dash_glue42'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'maxActions', 'raise', 'setProps']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Notifications, self).__init__(**args)
